@@ -54,7 +54,6 @@ var sNameProperty = null;
    in the other js file.
 */
 var msgWindow = Components.classes["@mozilla.org/messenger/msgwindow;1"].createInstance();
-msgWindow = msgWindow.QueryInterface(Components.interfaces.nsIMsgWindow);
 
 
 /**
@@ -96,7 +95,6 @@ var gCharsetConvertManager;
 
 var gLastWindowToHaveFocus;
 var gReceiptOptionChanged;
-var gAttachVCardOptionChanged;
 
 var gMailSession;
 
@@ -141,7 +139,6 @@ function InitializeGlobalVariables()
 
   gLastWindowToHaveFocus = null;
   gReceiptOptionChanged = false;
-  gAttachVCardOptionChanged = false;
 }
 InitializeGlobalVariables();
 
@@ -582,7 +579,6 @@ function updateComposeItems() {
 }
 
 function updateEditItems() {
-  goUpdateCommand("cmd_pasteNoFormatting");
   goUpdateCommand("cmd_pasteQuote");
   goUpdateCommand("cmd_delete");
   goUpdateCommand("cmd_selectAll");
@@ -1086,7 +1082,7 @@ function GetArgs(originalData)
       args[argname] = argvalue.substring(1, argvalue.length - 1);
     else
       try {
-        args[argname] = decodeURIComponent(argvalue);
+        args[argname] = unescape(argvalue);
       } catch (e) {args[argname] = argvalue;}
     dump("[" + argname + "=" + args[argname] + "]\n");
   }
@@ -1220,8 +1216,6 @@ function ComposeStartup(recycled, aParams)
       }
       document.getElementById("returnReceiptMenu").setAttribute('checked', 
                                          gMsgCompose.compFields.returnReceipt);
-      document.getElementById("cmd_attachVCard").setAttribute('checked', 
-                                         gMsgCompose.compFields.attachVCard);
 
       // If recycle, editor is already created
       if (!recycled) 
@@ -1261,10 +1255,9 @@ function ComposeStartup(recycled, aParams)
           {
             var cleanBody;
             try {
-              cleanBody = decodeURI(body);
+              cleanBody = unescape(body);
             } catch(e) { cleanBody = body;}
 
-            // XXX : need to do html-escaping here !
             msgCompFields.body = "<BR><A HREF=\"" + body + "\">" + cleanBody + "</A><BR>";
           }
           else
@@ -1670,9 +1663,7 @@ function GenericSendMessage( msgType )
           progress.registerListener(progressListener);
           gSendOrSaveOperationInProgress = true;
         }
-        msgWindow.SetDOMWindow(window);
-
-        gMsgCompose.SendMsg(msgType, getCurrentIdentity(), msgWindow, progress);
+        gMsgCompose.SendMsg(msgType, getCurrentIdentity(), progress);
       }
       catch (ex) {
         dump("failed to SendMsg: " + ex + "\n");
@@ -1739,8 +1730,6 @@ function Save()
 function SaveAsFile(saveAs)
 {
   dump("SaveAsFile from XUL\n");
-  var subject = document.getElementById('msgSubject').value;
-  GetCurrentEditor().setDocumentTitle(subject);
   if (gMsgCompose.bodyConvertible() == nsIMsgCompConvertible.Plain)
     SaveDocument(saveAs, false, "text/plain");
   else
@@ -1869,17 +1858,6 @@ function ToggleReturnReceipt(target)
     }
 }
 
-function ToggleAttachVCard(target)
-{
-    var msgCompFields = gMsgCompose.compFields;
-    if (msgCompFields)
-    {
-        msgCompFields.attachVCard = ! msgCompFields.attachVCard;
-        target.setAttribute('checked', msgCompFields.attachVCard);
-        gAttachVCardOptionChanged = true;
-    }
-}
-
 function queryISupportsArray(supportsArray, iid) {
     var result = new Array;
     for (var i=0; i<supportsArray.Count(); i++) {
@@ -2189,7 +2167,7 @@ function AddAttachment(attachment)
     item.setAttribute("label", attachment.name);    //use for display only
     item.attachment = attachment;   //full attachment object stored here
     try {
-      item.setAttribute("tooltiptext", decodeURI(attachment.url));
+      item.setAttribute("tooltiptext", unescape(attachment.url));
     } catch(e) {
       item.setAttribute("tooltiptext", attachment.url);
     }
@@ -2313,11 +2291,16 @@ function FocusOnFirstAttachment()
 
 function AttachmentElementHasItems()
 {
-  var element = document.getElementById("attachmentBucket");
+  var element = document.getElementById("bucketList");
 
   return element ? element.childNodes.length : 0;
 }  
 
+function AttachVCard()
+{
+  dump("AttachVCard()\n");
+}
+
 function DetermineHTMLAction(convertible)
 {
     var obj;
@@ -2428,7 +2411,6 @@ function LoadIdentity(startup)
           var prevReplyTo = prevIdentity.replyTo;
           var prevBcc = "";
           var prevReceipt = prevIdentity.requestReturnReceipt;
-          var prevAttachVCard = prevIdentity.attachVCard;
 
           if (prevIdentity.doBcc)
             prevBcc += prevIdentity.doBccList;
@@ -2436,8 +2418,6 @@ function LoadIdentity(startup)
           var newReplyTo = gCurrentIdentity.replyTo;
           var newBcc = "";
           var newReceipt = gCurrentIdentity.requestReturnReceipt;
-          var newAttachVCard = gCurrentIdentity.attachVCard;
-
           if (gCurrentIdentity.doBcc)
             newBcc += gCurrentIdentity.doBccList;          
 
@@ -2452,13 +2432,6 @@ function LoadIdentity(startup)
             document.getElementById("returnReceiptMenu").setAttribute('checked',msgCompFields.returnReceipt);
           }
 
-          if (!gAttachVCardOptionChanged &&
-              prevAttachVCard == msgCompFields.attachVCard &&
-              prevAttachVCard != newAttachVCard)
-          {
-            msgCompFields.attachVCard = newAttachVCard;
-            document.getElementById("cmd_attachVCard").setAttribute('checked',msgCompFields.attachVCard);
-          }
 
           if (newReplyTo != prevReplyTo)
           {
@@ -2565,10 +2538,18 @@ function subjectKeyPress(event)
   }
 }
 
+function editorKeyPress(event)
+{
+  if (event.keyCode == 9) {
+    if (event.shiftKey && !event.getPreventDefault()) {
+      document.getElementById('msgSubject').focus();
+      event.preventDefault();
+    }
+  }
+}
+
 function AttachmentBucketClicked(event)
 {
-  event.currentTarget.focus();
-
   if (event.button != 0)
     return;
 
